﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.GanttView;
using Telerik.Windows.Controls.Scheduling;

namespace GanttMilitaryDates
{
    public class ViewModel : ViewModelBase
    {
        private ObservableCollection<IGanttTask> tasks;

        public ViewModel()
        {
            this.tasks = new SoftwarePlanning();

            var start = DateTime.Now.AddDays(-10);
            var end = start.AddDays(30);

            //var start = new DateTime(2012, 1, 3, 8, 0, 0);//this.tasks.Min(t => t.Start).Date;
            //var end = new DateTime(2012, 1, 6).AddDays(4);//this.tasks.Max(t => t.End).Date;

            this.visibleTime = new DateRange(start, end);
        }

        public IList Tasks { get { return this.tasks; } }

        private DateRange visibleTime;

        /// <Summary>Gets or sets VisibleTime and notifies for changes</Summary>
        public DateRange VisibleTime
        {
            get { return this.visibleTime; }
            set
            {
                if (this.visibleTime != value)
                {
                    this.visibleTime = value;
                    this.OnPropertyChanged(() => this.VisibleTime);
                }
            }
        }

        private DateTime dDate;
        public DateTime DDate
        {
            get { return this.dDate; }
            set
            {
                if (this.dDate != value)
                {
                    this.dDate = value;
                    this.OnPropertyChanged(() => this.DDate);
                    this.CalculateDates();
                }
            }
        }

        private void CalculateDates()
        {
            foreach (var task in this.tasks)
            {
                var customTask = (task as CustomGanttTask);
                if (customTask != null)
                {
                    customTask.SetStartEndByDDate(this.DDate);
                }
                this.CalculateChildDates(customTask);
            }
        }

        private void CalculateChildDates(CustomGanttTask parent)
        {
            foreach (var task in parent.Children)
            {
                var customTask = (task as CustomGanttTask);
                if (customTask != null)
                {
                    customTask.SetStartEndByDDate(this.DDate);
                }
            }
        }
    }
}
